=====
Usage
=====

User
~~~~

Get User's ID
-------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/c4e694ee6f2ede9d7261acd87152e8f7.js?file=get_user_id.py"></script>
	<script src="https://gist.github.com/weeping-angel/c4e694ee6f2ede9d7261acd87152e8f7.js?file=get_user_id_output.txt"></script>


Get User's Info
---------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/59b73002c496c03e27e22a6f656bf8f0.js?file=get_user_info.py"></script>
	<script src="https://gist.github.com/weeping-angel/59b73002c496c03e27e22a6f656bf8f0.js?file=get_user_info_output.txt"></script>


Get User's Articles
-------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/9029e637155ebc4038ecc3930af93913.js?file=get_user_articles.py"></script>
	<script src="https://gist.github.com/weeping-angel/9029e637155ebc4038ecc3930af93913.js?file=get_user_articles_output.txt"></script>


Get User's Interests
---------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/9f5e2e0d2ce6d00694406dcd7487d5b3.js?file=get_user_interests.py"></script>
	<script src="https://gist.github.com/weeping-angel/9f5e2e0d2ce6d00694406dcd7487d5b3.js?file=get_user_interests_output.txt"></script>


Get User's Top Articles
-----------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/75c9cbd400470261dd25a2b9354dd279.js?file=get_user_top_articles.py"></script>
	<script src="https://gist.github.com/weeping-angel/75c9cbd400470261dd25a2b9354dd279.js?file=get_user_top_articles_output.txt"></script>


Get User's Followers
--------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/7432d0edaa73d690b3e84224dd127d0c.js?file=get_user_followers.py"></script>
	<script src="https://gist.github.com/weeping-angel/7432d0edaa73d690b3e84224dd127d0c.js?file=get_user_followers_output.txt"></script>


Get User's Following
--------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/cc9b4660765d52bff85fa9a80c66002c.js?file=get_user_following.py"></script>
	<script src="https://gist.github.com/weeping-angel/cc9b4660765d52bff85fa9a80c66002c.js?file=get_user_following_output.txt"></script>


Article
~~~~~~~~~

Get Article's Info
-------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/4cfd6c9716cb4c4763ffd20bb820e9c8.js?file=get_article_info.py"></script>
	<script src="https://gist.github.com/weeping-angel/4cfd6c9716cb4c4763ffd20bb820e9c8.js?file=get_article_info_output.txt"></script>


Get Article's Content
---------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/dc469baf9aa845282773c50bad54bb4f.js?file=get_article_content.py"></script>
	<script src="https://gist.github.com/weeping-angel/dc469baf9aa845282773c50bad54bb4f.js?file=get_article_content_output.txt"></script>


Get Article's Markdown
-----------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/f361d734893eabe095492e86c5f5b1aa.js?file=get_article_markdown.py"></script>
	<script src="https://gist.github.com/weeping-angel/f361d734893eabe095492e86c5f5b1aa.js?file=get_article_markdown_output.txt"></script>


Get Article's Responses
-----------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/02c8403dd20baab9a92abe73253f89c1.js?file=get_article_responses.py"></script>
	<script src="https://gist.github.com/weeping-angel/02c8403dd20baab9a92abe73253f89c1.js?file=get_article_responses_output.txt"></script>

Publication
~~~~~~~~~~~~

Get Publication ID
------------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/4e15df195145eae3ecc9cdb5a84e2428.js?file=get_publication_id.py"></script>
	<script src="https://gist.github.com/weeping-angel/4e15df195145eae3ecc9cdb5a84e2428.js?file=get_publication_id_output.txt"></script>


Get Publication's Info
------------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/1f9ee9f7fe6f31ba0a26d537ccc2c145.js?file=get_publication_info.py"></script>
	<script src="https://gist.github.com/weeping-angel/1f9ee9f7fe6f31ba0a26d537ccc2c145.js?file=get_publication_info_output.txt"></script>


Get Publication's Articles
----------------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/ae1f46c117a69428218beb74fc641c3e.js?file=get_publication_articles.py"></script>
	<script src="https://gist.github.com/weeping-angel/ae1f46c117a69428218beb74fc641c3e.js?file=get_publication_articles_output.txt"></script>


Get Publication's Newsletter
-------------------------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/4690dfa2431d3909789917a45183eb5f.js?file=get_publication_newsletter.py"></script>
	<script src="https://gist.github.com/weeping-angel/4690dfa2431d3909789917a45183eb5f.js?file=get_publication_newsletter_output.txt"></script>


Misc
~~~~~

Get TopFeeds
------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/72a58e9bc6b969a7d8053d624715790f.js?file=get_topfeeds.py"></script>
	<script src="https://gist.github.com/weeping-angel/72a58e9bc6b969a7d8053d624715790f.js?file=get_topfeeds_output.txt"></script>


Get LatestPosts
---------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/5e47c3732280e37887c8adbd9b0efa3b.js?file=get_latestposts.py"></script>
	<script src="https://gist.github.com/weeping-angel/5e47c3732280e37887c8adbd9b0efa3b.js?file=get_latestposts_output.txt"></script>

Get Top Writers
---------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/eecb654b0b04224de5473167302e964a.js?file=get_top_writers.py"></script>
	<script src="https://gist.github.com/weeping-angel/eecb654b0b04224de5473167302e964a.js?file=get_top_writers_output.txt"></script>

Get Related Tags
----------------

.. raw:: html

	<script src="https://gist.github.com/weeping-angel/3a10f33e695e1286b14dcc98d6df81c3.js?file=get_related_tags.py"></script>
	<script src="https://gist.github.com/weeping-angel/3a10f33e695e1286b14dcc98d6df81c3.js?file=get_related_tags_output.txt"></script>